# Aadhaar Card Information Extractor
This project is an implementation of OCR (Optical Character Recognition) to extract relevant information from an Aadhaar card.

Deployed App available [here](Dhttps://cvaproject-aadhaarcardin-aadhar-info-extractor-streamlit-0gi7up.streamlit.app/)

## IMPORTANT
### Please ensure you have pytesseract installed in the following path:
`C:\Program Files\Tesseract-OCR\tesseract.exe`

## USAGE
Just type `acie` followed by the filename argument, for example:

`acie filename.jpg`